@@ -11,6 +11,7 @@ from music.models import Track
 from podcasts.models import Episode
 from scrobbles.utils import check_scrobble_for_finish
 from videos.models import Video
+from sports.models import SportEvent
 
 logger = logging.getLogger(__name__)
 User = get_user_model()
@@ -27,6 +28,9 @@ class Scrobble(TimeStampedModel):
     podcast_episode = models.ForeignKey(
         Episode, on_delete=models.DO_NOTHING, **BNULL
     )
+    sport_event = models.ForeignKey(
+        SportEvent, on_delete=models.DO_NOTHING, **BNULL
+    )
     user = models.ForeignKey(
         User, blank=True, null=True, on_delete=models.DO_NOTHING
     )
@@ -73,6 +77,8 @@ class Scrobble(TimeStampedModel):
             media_obj = self.track
         if self.podcast_episode:
             media_obj = self.podcast_episode
+        if self.sport_event:
+            media_obj = self.sport_event
         return media_obj
 
     def __str__(self):
@@ -83,9 +89,6 @@ class Scrobble(TimeStampedModel):
         cls, video: "Video", user_id: int, jellyfin_data: dict
     ) -> "Scrobble":
         jellyfin_data['video_id'] = video.id
-        logger.debug(
-            f"Creating or updating scrobble for video {video} with data {jellyfin_data}"
-        )
         scrobble = (
             cls.objects.filter(video=video, user_id=user_id)
             .order_by('-modified')
@@ -110,10 +113,11 @@ class Scrobble(TimeStampedModel):
             .order_by('-modified')
             .first()
         )
-        logger.debug(
-            f"Found existing scrobble for track {track}, updating",
-            {"scrobble_data": scrobble_data},
-        )
+        if scrobble:
+            logger.debug(
+                f"Found existing scrobble for track {track}, updating",
+                {"scrobble_data": scrobble_data},
+            )
 
         backoff = timezone.now() + timedelta(seconds=TRACK_BACKOFF)
         wait_period = timezone.now() + timedelta(minutes=TRACK_WAIT_PERIOD)
@@ -144,6 +148,25 @@ class Scrobble(TimeStampedModel):
             scrobble, backoff, wait_period, scrobble_data
         )
 
+    @classmethod
+    def create_or_update_for_sport_event(
+        cls, event: "SportEvent", user_id: int, jellyfin_data: dict
+    ) -> "Scrobble":
+        jellyfin_data['sport_event_id'] = event.id
+        scrobble = (
+            cls.objects.filter(sport_event=event, user_id=user_id)
+            .order_by('-modified')
+            .first()
+        )
+
+        # Backoff is how long until we consider this a new scrobble
+        backoff = timezone.now() + timedelta(minutes=VIDEO_BACKOFF)
+        wait_period = timezone.now() + timedelta(days=VIDEO_WAIT_PERIOD)
+
+        return cls.update_or_create(
+            scrobble, backoff, wait_period, jellyfin_data
+        )
+
     @classmethod
     def update_or_create(
         cls,
@@ -163,8 +186,10 @@ class Scrobble(TimeStampedModel):
             )
             return
 
-        logger.debug(f"Scrobbling to {scrobble} with status {scrobble_status}")
         if scrobble:
+            logger.debug(
+                f"Scrobbling to {scrobble} with status {scrobble_status}"
+            )
             scrobble.update_ticks(scrobble_data)
 
             # On stop, stop progress and send it to the check for completion
@@ -178,57 +203,55 @@ class Scrobble(TimeStampedModel):
             if scrobble_status == "resumed":
                 return scrobble.resume()
 
-            # We're not changing the scrobble, but we don't want to walk over an existing one
-            scrobble_is_finished = (
-                not scrobble.in_progress and scrobble.modified < backoff
-            )
-            if scrobble_is_finished:
-                logger.info(
-                    'Found a very recent scrobble for this item, holding off scrobbling again'
-                )
-                return
+            for key, value in scrobble_data.items():
+                setattr(scrobble, key, value)
+            scrobble.save()
 
-        if not scrobble:
+            # We're not changing the scrobble, but we don't want to walk over an existing one
+            # scrobble_is_finished = (
+            #    not scrobble.in_progress and scrobble.modified < backoff
+            # )
+            # if scrobble_is_finished:
+            #    logger.info(
+            #        'Found a very recent scrobble for this item, holding off scrobbling again'
+            #    )
+            #    return
+            check_scrobble_for_finish(scrobble)
+        else:
+            logger.debug(
+                f"Creating new scrobble with status {scrobble_status}"
+            )
             # If we default this to "" we can probably remove this
             scrobble_data['scrobble_log'] = ""
             scrobble = cls.objects.create(
                 **scrobble_data,
             )
-        else:
-            for key, value in scrobble_data.items():
-                setattr(scrobble, key, value)
-            scrobble.save()
-
-        # If we hit our completion threshold, save it and get ready
-        # to scrobble again if we re-watch this.
-        scrobble = check_scrobble_for_finish(scrobble)
 
         return scrobble
 
-    def stop(self):
+    def stop(self) -> None:
         if not self.in_progress:
             logger.warning("Scrobble already stopped")
             return
         self.in_progress = False
         self.save(update_fields=['in_progress'])
-        return check_scrobble_for_finish(self)
+        check_scrobble_for_finish(self)
 
-    def pause(self):
+    def pause(self) -> None:
         if self.is_paused:
             logger.warning("Scrobble already paused")
             return
         self.is_paused = True
         self.save(update_fields=["is_paused"])
-        return check_scrobble_for_finish(self)
+        check_scrobble_for_finish(self)
 
-    def resume(self):
+    def resume(self) -> None:
         if self.is_paused or not self.in_progress:
             self.is_paused = False
             self.in_progress = True
             return self.save(update_fields=["is_paused", "in_progress"])
-        return self
 
-    def update_ticks(self, data):
+    def update_ticks(self, data) -> None:
         self.playback_position_ticks = data.get("playback_position_ticks")
         self.playback_position = data.get("playback_position")
         logger.debug(
@@ -237,4 +260,3 @@ class Scrobble(TimeStampedModel):
         self.save(
             update_fields=['playback_position_ticks', 'playback_position']
         )
-        return self
