@@ -16,16 +16,19 @@ from scrobbles.constants import (
     JELLYFIN_AUDIO_ITEM_TYPES,
     JELLYFIN_VIDEO_ITEM_TYPES,
 )
+from scrobbles.forms import ScrobbleForm
 from scrobbles.imdb import lookup_video_from_imdb
 from scrobbles.models import Scrobble
 from scrobbles.scrobblers import (
     jellyfin_scrobble_track,
     jellyfin_scrobble_video,
+    manual_scrobble_event,
     manual_scrobble_video,
     mopidy_scrobble_podcast,
     mopidy_scrobble_track,
 )
 from scrobbles.serializers import ScrobbleSerializer
+from scrobbles.thesportsdb import lookup_event_from_thesportsdb
 
 from vrobbler.apps.music.aggregators import (
     scrobble_counts,
@@ -33,7 +36,6 @@ from vrobbler.apps.music.aggregators import (
     top_tracks,
     week_of_scrobbles,
 )
-from scrobbles.forms import ImdbScrobbleForm
 
 logger = logging.getLogger(__name__)
 
@@ -63,10 +65,13 @@ class RecentScrobbleList(ListView):
         )
         data['video_scrobble_list'] = Scrobble.objects.filter(
             video__isnull=False, played_to_completion=True
-        ).order_by('-timestamp')[:10]
+        ).order_by('-timestamp')[:15]
         data['podcast_scrobble_list'] = Scrobble.objects.filter(
             podcast_episode__isnull=False, played_to_completion=True
-        ).order_by('-timestamp')[:10]
+        ).order_by('-timestamp')[:15]
+        data['sport_scrobble_list'] = Scrobble.objects.filter(
+            sport_event__isnull=False, played_to_completion=True
+        ).order_by('-timestamp')[:15]
         data['top_daily_tracks'] = top_tracks()
         data['top_weekly_tracks'] = top_tracks(filter='week')
         data['top_monthly_tracks'] = top_tracks(filter='month')
@@ -77,7 +82,7 @@ class RecentScrobbleList(ListView):
 
         data["weekly_data"] = week_of_scrobbles()
         data['counts'] = scrobble_counts()
-        data['imdb_form'] = ImdbScrobbleForm
+        data['imdb_form'] = ScrobbleForm
         return data
 
     def get_queryset(self):
@@ -86,16 +91,28 @@ class RecentScrobbleList(ListView):
         ).order_by('-timestamp')[:15]
 
 
-class ManualImdbScrobbleView(FormView):
-    form_class = ImdbScrobbleForm
+class ManualScrobbleView(FormView):
+    form_class = ScrobbleForm
     template_name = 'scrobbles/manual_form.html'
 
     def form_valid(self, form):
 
-        # look for video via IMDB id
-        data_dict = lookup_video_from_imdb(form.cleaned_data.get('imdb_id'))
+        item_id = form.cleaned_data.get('item_id')
+        data_dict = None
+        if 'tt' in item_id:
+            data_dict = lookup_video_from_imdb(
+                form.cleaned_data.get('item_id')
+            )
+            if data_dict:
+                manual_scrobble_video(data_dict, self.request.user.id)
 
-        manual_scrobble_video(data_dict, self.request.user.id)
+        if not data_dict:
+            logger.debug(f"Looking for sport event with ID {item_id}")
+            data_dict = lookup_event_from_thesportsdb(
+                form.cleaned_data.get('item_id')
+            )
+            if data_dict:
+                manual_scrobble_event(data_dict, self.request.user.id)
 
         return HttpResponseRedirect(reverse("home"))
 
